@@ -1,5 +1,4 @@
 
-
 from ..client import Client
 
 
@@ -8,12 +7,12 @@ class Reports(Client):
     def request_report(self, record_type, data):
         self.uri_path = "/v2/hsa/{}/report".format(record_type)
         self.method = "post"
-        self.data = params
+        self.data = data
         return self.execute()
 
     def get_report(self, report_id):
-        self.method = "get"
         self.uri_path = "/v2/reports/{}".format(report_id)
+        self.method = "get"
         return self.execute()
 
     def get_report_download_url(self, location):
@@ -26,4 +25,3 @@ class Reports(Client):
         self.headers.pop("Content-Type")
         self.headers["Accept-encoding"] = "gzip"
         return self.execute()
-
